/*
 Copyright (C) 2016 - 2018, 2020 - 2021 3NSoft Inc.
 
 This program is free software: you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free Software
 Foundation, either version 3 of the License, or (at your option) any later
 version.
 
 This program is distributed in the hope that it will be useful, but
 WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 See the GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License along with
 this program. If not, see <http://www.gnu.org/licenses/>.
*/
import { stringifyErr } from "../../lib-common/exceptions/error.js";
import { callWithTimeout } from "../../lib-common/processes/timeouts.js";
export function itCond(expectation, assertion, timeout, setup) {
    if (assertion) {
        it(expectation, callbackFor(assertion, setup), timeout);
    }
    else {
        it(expectation);
    }
}
function callbackFor(assertion, setup) {
    return async () => {
        if (setup && !setup.isUp) {
            fail(`Test setup is not up`);
        }
        else {
            try {
                await assertion();
            }
            catch (err) {
                if (typeof err === 'string') {
                    fail(err);
                }
                else if (err.runtimeException) {
                    fail(stringifyErr(err));
                }
                else {
                    throw err;
                }
            }
        }
    };
}
export function xitCond(expectation, assertion, timeout, setup) {
    if (assertion) {
        xit(expectation, callbackFor(assertion, setup), timeout);
    }
    else {
        xit(expectation);
    }
}
export function fitCond(expectation, assertion, timeout, setup) {
    if (assertion) {
        fit(expectation, callbackFor(assertion, setup), timeout);
    }
    else {
        fit(expectation);
    }
}
export function beforeAllWithTimeoutLog(action, timeout) {
    beforeAll(callbackWithTimeout(action, true, timeout, 'beforeAll'), timeout);
}
const DEFAULT_TIMEOUT_INTERVAL = 5000;
function callbackWithTimeout(action, throwIfErr, timeout, actionType) {
    const millisToSleep = ((timeout === undefined) ?
        DEFAULT_TIMEOUT_INTERVAL : timeout);
    const timeoutErr = {};
    return async () => {
        try {
            await callWithTimeout(action, millisToSleep - 5, () => timeoutErr);
        }
        catch (err) {
            if (err === timeoutErr) {
                console.log(`\n>>> timeout in ${actionType}: action hasn't completed in ${millisToSleep - 5} milliseconds`);
            }
            else if (throwIfErr) {
                if (typeof err === 'string') {
                    fail(err);
                }
                else if (err.runtimeException) {
                    fail(stringifyErr(err));
                }
                else {
                    throw err;
                }
            }
        }
    };
}
export function beforeEachWithTimeoutLog(action, timeout) {
    beforeEach(callbackWithTimeout(action, true, timeout, 'beforeEach'), timeout);
}
// Adjust this static flag to hide/show errors thrown in afterXXX()
const throwErrorInAfter = false;
export function afterAllCond(action, timeout) {
    afterAll(callbackWithTimeout(action, throwErrorInAfter, timeout, 'afterAll'), timeout);
}
export function afterEachCond(action, timeout) {
    afterEach(callbackWithTimeout(action, throwErrorInAfter, timeout, 'afterEach'), timeout);
}
//# sourceMappingURL=jasmine-utils.js.map